var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import axios from "axios";
import GlueEvent from "../glue-event";
import AUTH_EVENT_CONSTANTS from "./event-constants";
import IAuthProviderEnum from "./interfaces/IAuthProviderEnum";
export class Auth {
    constructor(AUTH_BASE_URL, GLUE, AUTH_TOKEN) {
        this.authBaseUrl = "";
        this.authToken = "";
        this.authBaseUrl = AUTH_BASE_URL;
        this.authToken = AUTH_TOKEN !== null && AUTH_TOKEN !== void 0 ? AUTH_TOKEN : "";
        this.glue = GLUE;
    }
    loginWithEmailPassword(email, password) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { data } = yield axios.post(`${this.authBaseUrl}/authentication/signin`, {
                    email,
                    password,
                });
                if ((data === null || data === void 0 ? void 0 : data.success) && (data === null || data === void 0 ? void 0 : data.data)) {
                    this.setAuthToken(data.data.token);
                    return data === null || data === void 0 ? void 0 : data.data;
                }
                return data === null || data === void 0 ? void 0 : data.message;
            }
            catch (error) {
                let message = "Something went wrong";
                if (axios.isAxiosError(error)) {
                    message = error.message;
                }
                return message;
            }
        });
    }
    socialLogin(provider) {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
                window.onmessage = (event) => __awaiter(this, void 0, void 0, function* () {
                    if (event.data && typeof event.data === "string") {
                        const data = JSON.parse(event === null || event === void 0 ? void 0 : event.data);
                        if ("token" in data) {
                            this.setAuthToken(data.token);
                            try {
                                const userWithToken = yield this.getUser();
                                if (userWithToken) {
                                    resolve(userWithToken);
                                    return;
                                }
                            }
                            catch (error) {
                                resolve(null);
                            }
                        }
                    }
                });
                window.open(`${this.authBaseUrl}/authentication/signin/${provider}`, "_blank", "location=yes,height=570,width=520,scrollbars=yes,status=yes");
            }));
        });
    }
    signupWithEmail(name, email, password) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { data } = yield axios.post(`${this.authBaseUrl}/authentication/signup`, {
                    name,
                    email,
                    password,
                });
                if ((data === null || data === void 0 ? void 0 : data.success) && (data === null || data === void 0 ? void 0 : data.data)) {
                    this.setAuthToken(data.data.token);
                    return data === null || data === void 0 ? void 0 : data.data;
                }
                return data === null || data === void 0 ? void 0 : data.message;
            }
            catch (error) {
                let message = "Something went wrong";
                if (axios.isAxiosError(error)) {
                    message = error.message;
                }
                return message;
            }
        });
    }
    login(authObject) {
        return __awaiter(this, void 0, void 0, function* () {
            if ("provider" in authObject) {
                switch (authObject.provider) {
                    case IAuthProviderEnum.google:
                        return yield this.socialLogin(authObject.provider);
                    case IAuthProviderEnum.github:
                        return yield this.socialLogin(authObject.provider);
                    case IAuthProviderEnum.microsoft:
                        return yield this.socialLogin(authObject.provider);
                }
            }
            return yield this.loginWithEmailPassword(authObject.email, authObject.password);
        });
    }
    setAuthToken(_token) {
        this.authToken = _token;
        this.glue.dispatchEvent(GlueEvent(AUTH_EVENT_CONSTANTS.TOKEN_UPDATED, { detail: _token }));
        this.glue.dispatchEvent(GlueEvent(AUTH_EVENT_CONSTANTS.ALL, { detail: _token }));
        this.glue.dispatchEvent(GlueEvent(AUTH_EVENT_CONSTANTS.UPDATED, { detail: _token }));
        return this.authToken;
    }
    getAuthToken() {
        return this.authToken;
    }
    getUser() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.authToken) {
                try {
                    const { data } = yield axios.get(`${this.authBaseUrl}/authentication/me`, {
                        headers: {
                            "x-hasura-user-token": this.authToken,
                        },
                    });
                    return data;
                }
                catch (e) {
                    return null;
                }
            }
            return null;
        });
    }
    isLoggedIn() {
        return __awaiter(this, void 0, void 0, function* () {
            if (yield this.getUser()) {
                return true;
            }
            return false;
        });
    }
}
//# sourceMappingURL=index.js.map